==> haskell-crypton-x509-store-1.6.12-1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.12
visibility:           public
id:                   crypton-x509-store-1.6.12-8u0cMDz1Er0H0crmNaS9QT
key:                  crypton-x509-store-1.6.12-8u0cMDz1Er0H0crmNaS9QT
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  d489242dc5c40641e1a2221cf5754638
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.12-8u0cMDz1Er0H0crmNaS9QT
depends:
    asn1-encoding-0.9.6-f2brNU34Hf3xe9CSPQRHn
    asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-11gen3PFWz54w2m32bVEwY
    crypton-x509-1.7.7-36kCqNSNK3p1rkA4mLjsoT directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 pem-0.2.4-BtvjegbjHoRAGAf9oBrW3C
    unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-store-1.6.12-2-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.12
visibility:           public
id:                   crypton-x509-store-1.6.12-Kpp5jEsJnJk1mLM8EMOCOC
key:                  crypton-x509-store-1.6.12-Kpp5jEsJnJk1mLM8EMOCOC
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  0a8bc847ad944842426cc6f21c031318
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-store-1.6.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.12-Kpp5jEsJnJk1mLM8EMOCOC
depends:
    asn1-encoding-0.9.6-4rkJHO0pUeFCGFdsLyrUdt
    asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI
    crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 pem-0.2.4-G3GIG2bUe0L9P6z0Mw3OGw
    unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
